@@ -3,6 +3,9 @@ import uvloop
 
 from abc import ABCMeta, abstractmethod
 
+from addict import Dict
+from sanic.request import RequestParameters
+
 from ddd.utils.dep_mgr import DependencyManager
 from ddd.tests.base_test_case import BaseTestCase
 
@@ -78,6 +81,54 @@ class ActionTestCase(BaseTestCase, metaclass=ABCMeta):
         elif self.config.pubsub.interchange.provider == "azure":
             await asyncio.sleep(1.5)
 
+    # Requests
+
+    def _create_request(
+        self,
+        token=None,
+        headers=None,
+        query_args=None,
+        form=None,
+        body=None,
+        json_=None,
+    ):
+        """
+        Create a sanice request for use by tests.
+        """
+        headers = headers if headers is not None else {}
+        query_args = query_args if query_args is not None else {}
+        form = form if form is not None else {}
+
+        if json_ is not None and body is not None:
+            raise Exception("Pass either 'json_' or 'body'.")
+
+        if json_ is not None:
+            body = json.dumps(json_)
+        else:
+            body = body if body is not None else ""
+
+        headers.update({
+            'X-TOKEN': token,
+        })
+
+        request = \
+            Dict({
+                'headers': headers,
+                'args': query_args,
+                'form': form,
+                'body': body.encode('utf-8'),
+                'json': json_,
+            })
+
+        request.args = \
+            RequestParameters(
+                {
+                    k: (v if isinstance(v, list) else [v])
+                    for k, v in query_args.items()
+                }
+            )
+
+        return request
 
     # Assert
 
